pub struct SvdPullback { /* private fields */ }Implementations
Sourceimpl SvdPullback
impl SvdPullback
Sourcepub fn values_backward(&self, ds: &[f64]) -> Result<Matrix, SolverError>
pub fn values_backward(&self, ds: &[f64]) -> Result<Matrix, SolverError>
Singular-value-only VJP. Rejects zero/repeated values rather than returning an arbitrary nonsmooth derivative. Values gradients must be finite.
Sourcepub fn backward(
&self,
du: MatrixView<'_>,
ds: &[f64],
dvt: MatrixView<'_>,
) -> Result<Matrix, SolverError>
pub fn backward( &self, du: MatrixView<'_>, ds: &[f64], dvt: MatrixView<'_>, ) -> Result<Matrix, SolverError>
Full thin-SVD VJP for nonzero, distinct singular values. Singular vector signs/bases must be used consistently with this exact forward result.